@@ -20,26 +20,17 @@ import javax.crypto.spec.SecretKeySpec;
  * @author Hiroyuki Shiota
  */
 public class DES {
-	public static final String DES_ALGORITHM = "DES";
-	public static final String DESEDE_ALGORITHM = "DESede";
-	public static final String AES_ALGORITHM = "AES";
-	public static final String BLOWFISH_ALGORITHM = "Blowfish";
-	public static final String RC2_ALGORITHM = "RC2";
-	public static final String RC4_ALGORITHM = "RC4";
-	private String algorithm = DES_ALGORITHM;
+	public static final String DES = "DES";
+	public static final String DESEDE = "DESede";
+	public static final String AES = "AES";
+	public static final String BLOWFISH = "Blowfish";
+	public static final String RC2 = "RC2";
+	public static final String RC4 = "RC4";
 
 	/**
 	 * ftHg̃ASY
 	 */
-	public DES() {
-	}
-
-	/**
-	 * ASYw肷RXgN^
-	 * @param algorithm
-	 */
-	public DES(String algorithm) {
-		this.algorithm = algorithm;
+	private DES() {
 	}
 
 	/**
@@ -48,7 +39,6 @@ public class DES {
 	 * @return
 	 */
 	public static String encodeBASE64(byte[] bytes) {
-		//return (new BASE64Encoder()).encodeBuffer(bytes);
 		return BASE64.encodeBytes(bytes);
 	}
 
@@ -59,7 +49,6 @@ public class DES {
 	 * @throws IOException
 	 */
 	public static byte[] decodeBASE64(String value) throws IOException {
-		//return (new BASE64Decoder()).decodeBuffer(value);
 		return BASE64.decode(value);
 	}
 
@@ -69,8 +58,8 @@ public class DES {
 	 * @throws NoSuchAlgorithmException
 	 * @throws IOException
 	 */
-	public String createKey() throws NoSuchAlgorithmException, IOException {
-		return createKey(null);
+	public static String createKey(String algorithm) throws NoSuchAlgorithmException, IOException {
+		return createKey(algorithm, null);
 	}
 
 	/**
@@ -80,7 +69,7 @@ public class DES {
 	 * @throws NoSuchAlgorithmException
 	 * @throws IOException
 	 */
-	public String createKey(String seed) throws NoSuchAlgorithmException, IOException {
+	public static String createKey(String algorithm, String seed) throws NoSuchAlgorithmException, IOException {
 		SecureRandom secureRandom = null;
 		if (seed != null) {
 			secureRandom = new SecureRandom(decodeBASE64(seed));
@@ -97,7 +86,7 @@ public class DES {
 	 * L[̎擾B
 	 * @param key
 	 */
-	private Key asKey(byte[] key) {
+	private static Key asKey(String algorithm, byte[] key) {
 		SecretKey secretKey = new SecretKeySpec(key, algorithm);
 		return secretKey;
 	}
@@ -114,9 +103,9 @@ public class DES {
 	 * @throws IllegalBlockSizeException
 	 * @throws BadPaddingException
 	 */
-	public byte[] encrypt(byte[] data, String key) throws IOException, NoSuchAlgorithmException,
+	public static byte[] encrypt(String algorithm, byte[] data, String key) throws IOException, NoSuchAlgorithmException,
 			NoSuchPaddingException, InvalidKeyException, IllegalBlockSizeException, BadPaddingException {
-		Key secretKey = asKey(decodeBASE64(key));
+		Key secretKey = asKey(algorithm, decodeBASE64(key));
 		Cipher cipher = Cipher.getInstance(algorithm);
 		cipher.init(Cipher.ENCRYPT_MODE, secretKey);
 		return cipher.doFinal(data);
@@ -134,9 +123,9 @@ public class DES {
 	 * @throws IllegalBlockSizeException
 	 * @throws BadPaddingException
 	 */
-	public byte[] decrypt(byte[] data, String key) throws IOException, NoSuchAlgorithmException,
+	public static byte[] decrypt(String algorithm, byte[] data, String key) throws IOException, NoSuchAlgorithmException,
 			NoSuchPaddingException, InvalidKeyException, IllegalBlockSizeException, BadPaddingException {
-		Key secretKey = asKey(decodeBASE64(key));
+		Key secretKey = asKey(algorithm, decodeBASE64(key));
 		Cipher cipher = Cipher.getInstance(algorithm);
 		cipher.init(Cipher.DECRYPT_MODE, secretKey);
 		return cipher.doFinal(data);
